@@ -743,7 +743,7 @@ get_translated_territory (const char *code,
         name = NULL;
         if (territory != NULL) {
                 const char *translated_territory;
-                locale_t loc;
+                locale_t loc = (locale_t) 0;
                 g_autofree char *tmp = NULL;
 
                 if (locale == NULL) {
@@ -757,7 +757,8 @@ get_translated_territory (const char *code,
                 tmp = get_first_item_in_semicolon_list (translated_territory);
                 name = capitalize_utf8_string (tmp);
 
-                freelocale (loc);
+                if (loc)
+                        freelocale (loc);
         }
 
         return name;
