@@ -20,11 +20,34 @@
 
 #define GNOME_DESKTOP_USE_UNSTABLE_API
 
-#include <gdk/gdkx.h>
 #include <glib.h>
 #include <gtk/gtk.h>
 #include <libgnome-desktop/gnome-rr.h>
 
+static void
+print_modes (GnomeRROutput *output)
+{
+        guint i;
+        GnomeRRMode **modes;
+
+        g_print ("\tmodes:\n");
+        modes = gnome_rr_output_list_modes (output);
+        if (modes[0] == NULL) {
+                g_print ("\t\tno modes available\n");
+                return;
+        }
+
+        for (i = 0; modes[i] != NULL; i++) {
+                g_print("\t\t");
+                g_print("id: %u", gnome_rr_mode_get_id (modes[i]));
+                g_print(", %ux%u%s", gnome_rr_mode_get_width (modes[i]), gnome_rr_mode_get_height (modes[i]),
+                        gnome_rr_mode_get_is_interlaced (modes[i]) ? "i" : "");
+                g_print(" (%i Hz)", gnome_rr_mode_get_freq (modes[i]));
+                g_print("%s", gnome_rr_mode_get_is_tiled (modes[i]) ? " (tiled)" : "");
+                g_print("\n");
+        }
+}
+
 static const char *
 dpms_mode_to_str (GnomeRRDpmsMode mode)
 {
@@ -50,8 +73,7 @@ print_output (GnomeRROutput *output, const char *message)
 	gsize len = 0;
 	const guint8 *result = NULL;
 	int width_mm, height_mm;
-	GnomeRRMode **modes;
-	int i;
+
 	g_print ("[%s]", gnome_rr_output_get_name (output));
 	if (message)
 		g_print (" (%s)", message);
@@ -83,13 +105,7 @@ print_output (GnomeRROutput *output, const char *message)
 		g_free (serial);
 	}
 
-	modes = gnome_rr_output_list_modes (output);
-	for (i = 0; modes[i] != NULL; ++i) {
-		g_print ("\t mode: %dx%d%s\n",
-			 gnome_rr_mode_get_width (modes[i]),
-			 gnome_rr_mode_get_height (modes[i]),
-			 gnome_rr_mode_get_is_tiled (modes[i]) ? " (tiled)" : "");
-	}
+	print_modes (output);
 	g_print ("\n");
 }
 
